#[repr(u8)]pub enum ExecutionStateLevel {
Inactive = 0,
Suspending = 1,
Active = 2,
UnknownOrdinal_(u8),
}Expand description
Execution state power levels
Elements should take an opportunistic dependency on ExecutionStateLevel::ACTIVE
to ensure that the element will be suspended when the rest of the system
suspends.
Drivers can take an opportunistic dependency on either
ExecutionStateLevel::SUSPENDING or ExecutionStateLevel::ACTIVE and
request a persistent lease on this state to ensure that their element’s
power level is always activated when the system comes out of a suspend
state.
Variants