pub struct ActivityGovernorAcquireLongWakeLeaseRequest {
pub name: String,
}Fields
name: StringTrait Implementations
Sourceimpl Clone for ActivityGovernorAcquireLongWakeLeaseRequest
impl Clone for ActivityGovernorAcquireLongWakeLeaseRequest
Sourcefn clone(&self) -> ActivityGovernorAcquireLongWakeLeaseRequest
fn clone(&self) -> ActivityGovernorAcquireLongWakeLeaseRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<ActivityGovernorAcquireLongWakeLeaseRequest<'static>, ___E> for &'a ActivityGovernorAcquireLongWakeLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ActivityGovernorAcquireLongWakeLeaseRequest<'static>, ___E> for &'a ActivityGovernorAcquireLongWakeLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ActivityGovernorAcquireLongWakeLeaseRequest<'static>, ___E> for ActivityGovernorAcquireLongWakeLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ActivityGovernorAcquireLongWakeLeaseRequest<'static>, ___E> for ActivityGovernorAcquireLongWakeLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireLongWakeLeaseRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ActivityGovernorAcquireLongWakeLeaseRequest<'static>>, ___E> for &'a ActivityGovernorAcquireLongWakeLeaseRequestwhere
___E: Encoder + ?Sized,
&'a ActivityGovernorAcquireLongWakeLeaseRequest: Encode<ActivityGovernorAcquireLongWakeLeaseRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ActivityGovernorAcquireLongWakeLeaseRequest<'static>>, ___E> for &'a ActivityGovernorAcquireLongWakeLeaseRequestwhere
___E: Encoder + ?Sized,
&'a ActivityGovernorAcquireLongWakeLeaseRequest: Encode<ActivityGovernorAcquireLongWakeLeaseRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireLongWakeLeaseRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireLongWakeLeaseRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireLongWakeLeaseRequest<'static>>, ___E> for ActivityGovernorAcquireLongWakeLeaseRequestwhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireLongWakeLeaseRequest: Encode<ActivityGovernorAcquireLongWakeLeaseRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireLongWakeLeaseRequest<'static>>, ___E> for ActivityGovernorAcquireLongWakeLeaseRequestwhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireLongWakeLeaseRequest: Encode<ActivityGovernorAcquireLongWakeLeaseRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireLongWakeLeaseRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireLongWakeLeaseRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ActivityGovernorAcquireLongWakeLeaseRequest<'de>> for ActivityGovernorAcquireLongWakeLeaseRequest
impl<'de> FromWire<ActivityGovernorAcquireLongWakeLeaseRequest<'de>> for ActivityGovernorAcquireLongWakeLeaseRequest
Sourcefn from_wire(wire: ActivityGovernorAcquireLongWakeLeaseRequest<'de>) -> Self
fn from_wire(wire: ActivityGovernorAcquireLongWakeLeaseRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ActivityGovernorAcquireLongWakeLeaseRequest<'de>> for ActivityGovernorAcquireLongWakeLeaseRequest
impl<'de> FromWireRef<ActivityGovernorAcquireLongWakeLeaseRequest<'de>> for ActivityGovernorAcquireLongWakeLeaseRequest
Sourcefn from_wire_ref(
wire: &ActivityGovernorAcquireLongWakeLeaseRequest<'de>,
) -> Self
fn from_wire_ref( wire: &ActivityGovernorAcquireLongWakeLeaseRequest<'de>, ) -> Self
Converts the given reference to this type.
Sourceimpl Ord for ActivityGovernorAcquireLongWakeLeaseRequest
impl Ord for ActivityGovernorAcquireLongWakeLeaseRequest
Sourcefn cmp(&self, other: &ActivityGovernorAcquireLongWakeLeaseRequest) -> Ordering
fn cmp(&self, other: &ActivityGovernorAcquireLongWakeLeaseRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ActivityGovernorAcquireLongWakeLeaseRequest
impl PartialEq for ActivityGovernorAcquireLongWakeLeaseRequest
Sourcefn eq(&self, other: &ActivityGovernorAcquireLongWakeLeaseRequest) -> bool
fn eq(&self, other: &ActivityGovernorAcquireLongWakeLeaseRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ActivityGovernorAcquireLongWakeLeaseRequest
impl PartialOrd for ActivityGovernorAcquireLongWakeLeaseRequest
impl Eq for ActivityGovernorAcquireLongWakeLeaseRequest
impl StructuralPartialEq for ActivityGovernorAcquireLongWakeLeaseRequest