pub struct ActivityGovernorAcquireWakeLeaseRequest {
pub name: String,
}Fields
name: StringTrait Implementations
Sourceimpl Clone for ActivityGovernorAcquireWakeLeaseRequest
impl Clone for ActivityGovernorAcquireWakeLeaseRequest
Sourcefn clone(&self) -> ActivityGovernorAcquireWakeLeaseRequest
fn clone(&self) -> ActivityGovernorAcquireWakeLeaseRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<ActivityGovernorAcquireWakeLeaseRequest<'static>, ___E> for &'a ActivityGovernorAcquireWakeLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ActivityGovernorAcquireWakeLeaseRequest<'static>, ___E> for &'a ActivityGovernorAcquireWakeLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ActivityGovernorAcquireWakeLeaseRequest<'static>, ___E> for ActivityGovernorAcquireWakeLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ActivityGovernorAcquireWakeLeaseRequest<'static>, ___E> for ActivityGovernorAcquireWakeLeaseRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ActivityGovernorAcquireWakeLeaseRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ActivityGovernorAcquireWakeLeaseRequest<'static>>, ___E> for &'a ActivityGovernorAcquireWakeLeaseRequestwhere
___E: Encoder + ?Sized,
&'a ActivityGovernorAcquireWakeLeaseRequest: Encode<ActivityGovernorAcquireWakeLeaseRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ActivityGovernorAcquireWakeLeaseRequest<'static>>, ___E> for &'a ActivityGovernorAcquireWakeLeaseRequestwhere
___E: Encoder + ?Sized,
&'a ActivityGovernorAcquireWakeLeaseRequest: Encode<ActivityGovernorAcquireWakeLeaseRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireWakeLeaseRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireWakeLeaseRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireWakeLeaseRequest<'static>>, ___E> for ActivityGovernorAcquireWakeLeaseRequestwhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireWakeLeaseRequest: Encode<ActivityGovernorAcquireWakeLeaseRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ActivityGovernorAcquireWakeLeaseRequest<'static>>, ___E> for ActivityGovernorAcquireWakeLeaseRequestwhere
___E: Encoder + ?Sized,
ActivityGovernorAcquireWakeLeaseRequest: Encode<ActivityGovernorAcquireWakeLeaseRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireWakeLeaseRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ActivityGovernorAcquireWakeLeaseRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ActivityGovernorAcquireWakeLeaseRequest<'de>> for ActivityGovernorAcquireWakeLeaseRequest
impl<'de> FromWire<ActivityGovernorAcquireWakeLeaseRequest<'de>> for ActivityGovernorAcquireWakeLeaseRequest
Sourcefn from_wire(wire: ActivityGovernorAcquireWakeLeaseRequest<'de>) -> Self
fn from_wire(wire: ActivityGovernorAcquireWakeLeaseRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ActivityGovernorAcquireWakeLeaseRequest<'de>> for ActivityGovernorAcquireWakeLeaseRequest
impl<'de> FromWireRef<ActivityGovernorAcquireWakeLeaseRequest<'de>> for ActivityGovernorAcquireWakeLeaseRequest
Sourcefn from_wire_ref(wire: &ActivityGovernorAcquireWakeLeaseRequest<'de>) -> Self
fn from_wire_ref(wire: &ActivityGovernorAcquireWakeLeaseRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for ActivityGovernorAcquireWakeLeaseRequest
impl Ord for ActivityGovernorAcquireWakeLeaseRequest
Sourcefn cmp(&self, other: &ActivityGovernorAcquireWakeLeaseRequest) -> Ordering
fn cmp(&self, other: &ActivityGovernorAcquireWakeLeaseRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ActivityGovernorAcquireWakeLeaseRequest
impl PartialEq for ActivityGovernorAcquireWakeLeaseRequest
Sourcefn eq(&self, other: &ActivityGovernorAcquireWakeLeaseRequest) -> bool
fn eq(&self, other: &ActivityGovernorAcquireWakeLeaseRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ActivityGovernorAcquireWakeLeaseRequest
impl PartialOrd for ActivityGovernorAcquireWakeLeaseRequest
impl Eq for ActivityGovernorAcquireWakeLeaseRequest
impl StructuralPartialEq for ActivityGovernorAcquireWakeLeaseRequest