BootControlServerHandler

Trait BootControlServerHandler 

pub trait BootControlServerHandler<___T: Transport = Channel> {
    // Required method
    fn set_boot_complete(
        &mut self,
        responder: Responder<SetBootComplete, ___T>,
    ) -> impl Future<Output = ()> + Send;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> + Send { ... }
}
A server handler for the BootControl protocol.

See BootControl for more details.

Required Methods

fn set_boot_complete( &mut self, responder: Responder<SetBootComplete, ___T>, ) -> impl Future<Output = ()> + Send

Notify the SAG that the system has booted. SAG will not suspend the hardware platform until this method is called at least once per boot.

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors